@@ -26,11 +26,19 @@ class ExcelDashboarder:
     const_str__config_label__str_format: str = "format"
     const_str__config_label__str_sheets: str = "sheets"
 
+    const_str__config_label__str_address: str = "address"
+    const_str__config_label__str_parameters_map: str = "parameters_map"
+    const_str__config_label__str_config: str = "config"
+
     const_str__config_label__str_vba: str = "vba"
     const_str__config_label__str_add_vba_project: str = "workbook.add_vba_project"
     const_str__config_label__str_wb_set_vba_name: str = "workbook.set_vba_name"
     const_str__config_label__str_ws_set_vba_name: str = "worksheet.set_vba_name"
 
+    const_str__config_label__str_ws_freeze_panes: str = "worksheet.freeze_panes"
+
+    const_str__config_label__str_wb_set_properties: str = "workbook.set_properties"
+
     _logger: Logger = getLogger(__name__)
 
     # This is the repository of all the registered widgets:
@@ -230,10 +238,10 @@ class ExcelDashboarder:
         dict_the_return: dict[str, Widget] = {}
 
         # We loop through each sheet
-        for i_sheet_name, i_sheet in dict_config["sheets"].items():
+        for i_sheet_name, i_sheet in dict_config[self.const_str__config_label__str_sheets].items():
 
             # We loop through each widget
-            for i_widget_label, i_widget in i_sheet["widgets"].items():
+            for i_widget_label, i_widget in i_sheet[self.const_str__config_label__str_widgets].items():
 
                 if i_widget_label in dict_the_return:
                     raise Exception(f"'{i_widget_label}' is defined several times in the configuration file, which is "
@@ -244,9 +252,9 @@ class ExcelDashboarder:
                 dict_the_return[i_widget_label] = dict_repository_of_widgets[
                     i_widget[Widget.const_str__config__widget_id]
                 ](
-                    str_address=i_widget["address"],
-                    dict_parameters_map=i_widget.get("parameters_map", {}),
-                    dict_config=i_widget.get("config", {}),
+                    str_address=i_widget[self.const_str__config_label__str_address],
+                    dict_parameters_map=i_widget.get(self.const_str__config_label__str_parameters_map, {}),
+                    dict_config=i_widget.get(self.const_str__config_label__str_config, {}),
 
                     # We only select the expected parameters, that we map to the labels expected by the widget
                     dict_raw_parameters=dict_raw_parameters,
@@ -292,8 +300,8 @@ class ExcelDashboarder:
             )
 
             # We freeze panes
-            if "worksheet.freeze_panes" in v_sheet:
-                ws_the_worksheet.freeze_panes(**v_sheet["worksheet.freeze_panes"])
+            if self.const_str__config_label__str_ws_freeze_panes in v_sheet:
+                ws_the_worksheet.freeze_panes(**v_sheet[self.const_str__config_label__str_ws_freeze_panes])
 
             # We write the widgets
             for k_widget, v_widget in v_sheet[self.const_str__config_label__str_widgets].items():
@@ -362,7 +370,7 @@ class ExcelDashboarder:
         self._logger.debug(f"Function '{stack()[0].filename} - {stack()[0].function}' is called")
 
         # We set properties
-        if "workbook.set_properties" in dict_config:
+        if self.const_str__config_label__str_wb_set_properties in dict_config:
             dt_the_created_date = dict_config["workbook.set_properties"].get("created", datetime.now())
             if isinstance(dt_the_created_date, str):
                 dt_the_created_date = datetime.fromisoformat(dt_the_created_date)
